==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/azurearcdata/kotlin/inputs/SqlManagedInstancePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurearcdata.kotlin.inputs

import com.pulumi.azurenative.azurearcdata.inputs.SqlManagedInstancePropertiesArgs.builder
import com.pulumi.azurenative.azurearcdata.kotlin.enums.ArcSqlManagedInstanceLicenseType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Properties of sqlManagedInstance.
 * @property activeDirectoryInformation Active Directory information related to this SQL Managed Instance.
 * @property admin The instance admin user
 * @property basicLoginInformation Username and password for basic authentication.
 * @property clusterId If a CustomLocation is provided, this contains the ARM id of the connected cluster the custom location belongs to.
 * @property dataControllerId null
 * @property endTime The instance end time
 * @property extensionId If a CustomLocation is provided, this contains the ARM id of the extension the custom location belongs to.
 * @property k8sRaw The raw kubernetes information
 * @property lastUploadedDate Last uploaded date from Kubernetes cluster. Defaults to current date time
 * @property licenseType The license type to apply for this managed instance.
 * @property startTime The instance start time
 */
public data class SqlManagedInstancePropertiesArgs(
    public val activeDirectoryInformation: Output<ActiveDirectoryInformationArgs>? = null,
    public val admin: Output<String>? = null,
    public val basicLoginInformation: Output<BasicLoginInformationArgs>? = null,
    public val clusterId: Output<String>? = null,
    public val dataControllerId: Output<String>? = null,
    public val endTime: Output<String>? = null,
    public val extensionId: Output<String>? = null,
    public val k8sRaw: Output<SqlManagedInstanceK8sRawArgs>? = null,
    public val lastUploadedDate: Output<String>? = null,
    public val licenseType: Output<Either<String, ArcSqlManagedInstanceLicenseType>>? = null,
    public val startTime: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.azurearcdata.inputs.SqlManagedInstancePropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.azurearcdata.inputs.SqlManagedInstancePropertiesArgs =
        com.pulumi.azurenative.azurearcdata.inputs.SqlManagedInstancePropertiesArgs.builder()
            .activeDirectoryInformation(
                activeDirectoryInformation?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .admin(admin?.applyValue({ args0 -> args0 }))
            .basicLoginInformation(
                basicLoginInformation?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .clusterId(clusterId?.applyValue({ args0 -> args0 }))
            .dataControllerId(dataControllerId?.applyValue({ args0 -> args0 }))
            .endTime(endTime?.applyValue({ args0 -> args0 }))
            .extensionId(extensionId?.applyValue({ args0 -> args0 }))
            .k8sRaw(k8sRaw?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .lastUploadedDate(lastUploadedDate?.applyValue({ args0 -> args0 }))
            .licenseType(
                licenseType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .startTime(startTime?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SqlManagedInstancePropertiesArgs].
 */
@PulumiTagMarker
public class SqlManagedInstancePropertiesArgsBuilder internal constructor() {
    private var activeDirectoryInformation: Output<ActiveDirectoryInformationArgs>? = null

    private var admin: Output<String>? = null

    private var basicLoginInformation: Output<BasicLoginInformationArgs>? = null

    private var clusterId: Output<String>? = null

    private var dataControllerId: Output<String>? = null

    private var endTime: Output<String>? = null

    private var extensionId: Output<String>? = null

    private var k8sRaw: Output<SqlManagedInstanceK8sRawArgs>? = null

    private var lastUploadedDate: Output<String>? = null

    private var licenseType: Output<Either<String, ArcSqlManagedInstanceLicenseType>>? = null

    private var startTime: Output<String>? = null

    /**
     * @param value Active Directory information related to this SQL Managed Instance.
     */
    @JvmName("kdijyytkkeowjutd")
    public suspend fun activeDirectoryInformation(`value`: Output<ActiveDirectoryInformationArgs>) {
        this.activeDirectoryInformation = value
    }

    /**
     * @param value The instance admin user
     */
    @JvmName("lceaoefxeaedcmto")
    public suspend fun admin(`value`: Output<String>) {
        this.admin = value
    }

    /**
     * @param value Username and password for basic authentication.
     */
    @JvmName("xfmqfsluxokwkhpr")
    public suspend fun basicLoginInformation(`value`: Output<BasicLoginInformationArgs>) {
        this.basicLoginInformation = value
    }

    /**
     * @param value If a CustomLocation is provided, this contains the ARM id of the connected cluster the custom location belongs to.
     */
    @JvmName("vebuwmliwwqaiuak")
    public suspend fun clusterId(`value`: Output<String>) {
        this.clusterId = value
    }

    /**
     * @param value null
     */
    @JvmName("fnuarxbfyluftmvn")
    public suspend fun dataControllerId(`value`: Output<String>) {
        this.dataControllerId = value
    }

    /**
     * @param value The instance end time
     */
    @JvmName("whckkqpvneruhoes")
    public suspend fun endTime(`value`: Output<String>) {
        this.endTime = value
    }

    /**
     * @param value If a CustomLocation is provided, this contains the ARM id of the extension the custom location belongs to.
     */
    @JvmName("emabjwydiroaicdd")
    public suspend fun extensionId(`value`: Output<String>) {
        this.extensionId = value
    }

    /**
     * @param value The raw kubernetes information
     */
    @JvmName("vrjldbaknrlqpehg")
    public suspend fun k8sRaw(`value`: Output<SqlManagedInstanceK8sRawArgs>) {
        this.k8sRaw = value
    }

    /**
     * @param value Last uploaded date from Kubernetes cluster. Defaults to current date time
     */
    @JvmName("vrbbndaqqvtfcvyv")
    public suspend fun lastUploadedDate(`value`: Output<String>) {
        this.lastUploadedDate = value
    }

    /**
     * @param value The license type to apply for this managed instance.
     */
    @JvmName("pijkmyhewesonpco")
    public suspend
    fun licenseType(`value`: Output<Either<String, ArcSqlManagedInstanceLicenseType>>) {
        this.licenseType = value
    }

    /**
     * @param value The instance start time
     */
    @JvmName("pllxbxnjjyykibea")
    public suspend fun startTime(`value`: Output<String>) {
        this.startTime = value
    }

    /**
     * @param value Active Directory information related to this SQL Managed Instance.
     */
    @JvmName("vhaybhoijnjqoxjl")
    public suspend fun activeDirectoryInformation(`value`: ActiveDirectoryInformationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.activeDirectoryInformation = mapped
    }

    /**
     * @param argument Active Directory information related to this SQL Managed Instance.
     */
    @JvmName("cvlurmmjecjsnncr")
    public suspend
    fun activeDirectoryInformation(argument: suspend ActiveDirectoryInformationArgsBuilder.() -> Unit) {
        val toBeMapped = ActiveDirectoryInformationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.activeDirectoryInformation = mapped
    }

    /**
     * @param value The instance admin user
     */
    @JvmName("kwrnrpijldxfmeyh")
    public suspend fun admin(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.admin = mapped
    }

    /**
     * @param value Username and password for basic authentication.
     */
    @JvmName("fumowuysrddbtwan")
    public suspend fun basicLoginInformation(`value`: BasicLoginInformationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.basicLoginInformation = mapped
    }

    /**
     * @param argument Username and password for basic authentication.
     */
    @JvmName("bifdomxoqrtirqcf")
    public suspend
    fun basicLoginInformation(argument: suspend BasicLoginInformationArgsBuilder.() -> Unit) {
        val toBeMapped = BasicLoginInformationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.basicLoginInformation = mapped
    }

    /**
     * @param value If a CustomLocation is provided, this contains the ARM id of the connected cluster the custom location belongs to.
     */
    @JvmName("kebqecadqpdxaxli")
    public suspend fun clusterId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterId = mapped
    }

    /**
     * @param value null
     */
    @JvmName("dwcdcuocjmulcibh")
    public suspend fun dataControllerId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataControllerId = mapped
    }

    /**
     * @param value The instance end time
     */
    @JvmName("vhdxxqbmtnyhfvvt")
    public suspend fun endTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endTime = mapped
    }

    /**
     * @param value If a CustomLocation is provided, this contains the ARM id of the extension the custom location belongs to.
     */
    @JvmName("jvrufywoullgainh")
    public suspend fun extensionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.extensionId = mapped
    }

    /**
     * @param value The raw kubernetes information
     */
    @JvmName("pjwepygrufcfqmoe")
    public suspend fun k8sRaw(`value`: SqlManagedInstanceK8sRawArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.k8sRaw = mapped
    }

    /**
     * @param argument The raw kubernetes information
     */
    @JvmName("qxflavddjrpvcree")
    public suspend fun k8sRaw(argument: suspend SqlManagedInstanceK8sRawArgsBuilder.() -> Unit) {
        val toBeMapped = SqlManagedInstanceK8sRawArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.k8sRaw = mapped
    }

    /**
     * @param value Last uploaded date from Kubernetes cluster. Defaults to current date time
     */
    @JvmName("gcrnljookddfshob")
    public suspend fun lastUploadedDate(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastUploadedDate = mapped
    }

    /**
     * @param value The license type to apply for this managed instance.
     */
    @JvmName("cuprwrrqvjirltql")
    public suspend fun licenseType(`value`: Either<String, ArcSqlManagedInstanceLicenseType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.licenseType = mapped
    }

    /**
     * @param value The license type to apply for this managed instance.
     */
    @JvmName("njaddbnihvrfnatr")
    public fun licenseType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ArcSqlManagedInstanceLicenseType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.licenseType = mapped
    }

    /**
     * @param value The license type to apply for this managed instance.
     */
    @JvmName("rfhvkrcoyshypyng")
    public fun licenseType(`value`: ArcSqlManagedInstanceLicenseType) {
        val toBeMapped = Either.ofRight<String, ArcSqlManagedInstanceLicenseType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.licenseType = mapped
    }

    /**
     * @param value The instance start time
     */
    @JvmName("hppppxeciqoobfte")
    public suspend fun startTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.startTime = mapped
    }

    internal fun build(): SqlManagedInstancePropertiesArgs = SqlManagedInstancePropertiesArgs(
        activeDirectoryInformation = activeDirectoryInformation,
        admin = admin,
        basicLoginInformation = basicLoginInformation,
        clusterId = clusterId,
        dataControllerId = dataControllerId,
        endTime = endTime,
        extensionId = extensionId,
        k8sRaw = k8sRaw,
        lastUploadedDate = lastUploadedDate,
        licenseType = licenseType,
        startTime = startTime,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/azurearcdata/kotlin/inputs/SqlManagedInstancePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurearcdata.kotlin.inputs

import com.pulumi.azurenative.azurearcdata.inputs.SqlManagedInstancePropertiesArgs.builder
import com.pulumi.azurenative.azurearcdata.kotlin.enums.ArcSqlManagedInstanceLicenseType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Properties of sqlManagedInstance.
 * @property activeDirectoryInformation Active Directory information related to this SQL Managed Instance.
 * @property admin The instance admin user
 * @property basicLoginInformation Username and password for basic authentication.
 * @property clusterId If a CustomLocation is provided, this contains the ARM id of the connected cluster the custom location belongs to.
 * @property dataControllerId null
 * @property endTime The instance end time
 * @property extensionId If a CustomLocation is provided, this contains the ARM id of the extension the custom location belongs to.
 * @property k8sRaw The raw kubernetes information
 * @property lastUploadedDate Last uploaded date from Kubernetes cluster. Defaults to current date time
 * @property licenseType The license type to apply for this managed instance.
 * @property startTime The instance start time
 */
public data class SqlManagedInstancePropertiesArgs(
    public val activeDirectoryInformation: Output<ActiveDirectoryInformationArgs>? = null,
    public val admin: Output<String>? = null,
    public val basicLoginInformation: Output<BasicLoginInformationArgs>? = null,
    public val clusterId: Output<String>? = null,
    public val dataControllerId: Output<String>? = null,
    public val endTime: Output<String>? = null,
    public val extensionId: Output<String>? = null,
    public val k8sRaw: Output<SqlManagedInstanceK8sRawArgs>? = null,
    public val lastUploadedDate: Output<String>? = null,
    public val licenseType: Output<Either<String, ArcSqlManagedInstanceLicenseType>>? = null,
    public val startTime: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.azurearcdata.inputs.SqlManagedInstancePropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.azurearcdata.inputs.SqlManagedInstancePropertiesArgs =
        com.pulumi.azurenative.azurearcdata.inputs.SqlManagedInstancePropertiesArgs.builder()
            .activeDirectoryInformation(
                activeDirectoryInformation?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .admin(admin?.applyValue({ args0 -> args0 }))
            .basicLoginInformation(
                basicLoginInformation?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .clusterId(clusterId?.applyValue({ args0 -> args0 }))
            .dataControllerId(dataControllerId?.applyValue({ args0 -> args0 }))
            .endTime(endTime?.applyValue({ args0 -> args0 }))
            .extensionId(extensionId?.applyValue({ args0 -> args0 }))
            .k8sRaw(k8sRaw?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .lastUploadedDate(lastUploadedDate?.applyValue({ args0 -> args0 }))
            .licenseType(
                licenseType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .startTime(startTime?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SqlManagedInstancePropertiesArgs].
 */
@PulumiTagMarker
public class SqlManagedInstancePropertiesArgsBuilder internal constructor() {
    private var activeDirectoryInformation: Output<ActiveDirectoryInformationArgs>? = null

    private var admin: Output<String>? = null

    private var basicLoginInformation: Output<BasicLoginInformationArgs>? = null

    private var clusterId: Output<String>? = null

    private var dataControllerId: Output<String>? = null

    private var endTime: Output<String>? = null

    private var extensionId: Output<String>? = null

    private var k8sRaw: Output<SqlManagedInstanceK8sRawArgs>? = null

    private var lastUploadedDate: Output<String>? = null

    private var licenseType: Output<Either<String, ArcSqlManagedInstanceLicenseType>>? = null

    private var startTime: Output<String>? = null

    /**
     * @param value Active Directory information related to this SQL Managed Instance.
     */
    @JvmName("sjfucbwjwxoyevhx")
    public suspend fun activeDirectoryInformation(`value`: Output<ActiveDirectoryInformationArgs>) {
        this.activeDirectoryInformation = value
    }

    /**
     * @param value The instance admin user
     */
    @JvmName("qobvvktaleuwonfe")
    public suspend fun admin(`value`: Output<String>) {
        this.admin = value
    }

    /**
     * @param value Username and password for basic authentication.
     */
    @JvmName("qgjddhmnraakgkgd")
    public suspend fun basicLoginInformation(`value`: Output<BasicLoginInformationArgs>) {
        this.basicLoginInformation = value
    }

    /**
     * @param value If a CustomLocation is provided, this contains the ARM id of the connected cluster the custom location belongs to.
     */
    @JvmName("fgburutghyxgkbqw")
    public suspend fun clusterId(`value`: Output<String>) {
        this.clusterId = value
    }

    /**
     * @param value null
     */
    @JvmName("hbibufmkbbkafima")
    public suspend fun dataControllerId(`value`: Output<String>) {
        this.dataControllerId = value
    }

    /**
     * @param value The instance end time
     */
    @JvmName("puiufhgpjevjgkhn")
    public suspend fun endTime(`value`: Output<String>) {
        this.endTime = value
    }

    /**
     * @param value If a CustomLocation is provided, this contains the ARM id of the extension the custom location belongs to.
     */
    @JvmName("fblclymddaldcewr")
    public suspend fun extensionId(`value`: Output<String>) {
        this.extensionId = value
    }

    /**
     * @param value The raw kubernetes information
     */
    @JvmName("ldspojsxlvbiwsxl")
    public suspend fun k8sRaw(`value`: Output<SqlManagedInstanceK8sRawArgs>) {
        this.k8sRaw = value
    }

    /**
     * @param value Last uploaded date from Kubernetes cluster. Defaults to current date time
     */
    @JvmName("aytmmyehlhmnjani")
    public suspend fun lastUploadedDate(`value`: Output<String>) {
        this.lastUploadedDate = value
    }

    /**
     * @param value The license type to apply for this managed instance.
     */
    @JvmName("ienioirrbxslnwgy")
    public suspend
    fun licenseType(`value`: Output<Either<String, ArcSqlManagedInstanceLicenseType>>) {
        this.licenseType = value
    }

    /**
     * @param value The instance start time
     */
    @JvmName("fvekctplldwwqjsf")
    public suspend fun startTime(`value`: Output<String>) {
        this.startTime = value
    }

    /**
     * @param value Active Directory information related to this SQL Managed Instance.
     */
    @JvmName("pnnultxnfjwnjvyc")
    public suspend fun activeDirectoryInformation(`value`: ActiveDirectoryInformationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.activeDirectoryInformation = mapped
    }

    /**
     * @param argument Active Directory information related to this SQL Managed Instance.
     */
    @JvmName("yijjjrfvqlvjhaxi")
    public suspend
    fun activeDirectoryInformation(argument: suspend ActiveDirectoryInformationArgsBuilder.() -> Unit) {
        val toBeMapped = ActiveDirectoryInformationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.activeDirectoryInformation = mapped
    }

    /**
     * @param value The instance admin user
     */
    @JvmName("vlkxlbjxjcxpyvsb")
    public suspend fun admin(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.admin = mapped
    }

    /**
     * @param value Username and password for basic authentication.
     */
    @JvmName("ghdicgxskgxdidjl")
    public suspend fun basicLoginInformation(`value`: BasicLoginInformationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.basicLoginInformation = mapped
    }

    /**
     * @param argument Username and password for basic authentication.
     */
    @JvmName("ysmsanlcpbeleqnt")
    public suspend
    fun basicLoginInformation(argument: suspend BasicLoginInformationArgsBuilder.() -> Unit) {
        val toBeMapped = BasicLoginInformationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.basicLoginInformation = mapped
    }

    /**
     * @param value If a CustomLocation is provided, this contains the ARM id of the connected cluster the custom location belongs to.
     */
    @JvmName("gshypbulymtplnle")
    public suspend fun clusterId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterId = mapped
    }

    /**
     * @param value null
     */
    @JvmName("jawodosaywaqnxvb")
    public suspend fun dataControllerId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataControllerId = mapped
    }

    /**
     * @param value The instance end time
     */
    @JvmName("nugfhtmajmpmwuse")
    public suspend fun endTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.endTime = mapped
    }

    /**
     * @param value If a CustomLocation is provided, this contains the ARM id of the extension the custom location belongs to.
     */
    @JvmName("hlxonkbaoajmtmsm")
    public suspend fun extensionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.extensionId = mapped
    }

    /**
     * @param value The raw kubernetes information
     */
    @JvmName("xoshymhsnsvynako")
    public suspend fun k8sRaw(`value`: SqlManagedInstanceK8sRawArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.k8sRaw = mapped
    }

    /**
     * @param argument The raw kubernetes information
     */
    @JvmName("ifykbqmgmcfeuwvu")
    public suspend fun k8sRaw(argument: suspend SqlManagedInstanceK8sRawArgsBuilder.() -> Unit) {
        val toBeMapped = SqlManagedInstanceK8sRawArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.k8sRaw = mapped
    }

    /**
     * @param value Last uploaded date from Kubernetes cluster. Defaults to current date time
     */
    @JvmName("chrmqovxymxfjlei")
    public suspend fun lastUploadedDate(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastUploadedDate = mapped
    }

    /**
     * @param value The license type to apply for this managed instance.
     */
    @JvmName("vxnmlkjlurafrvmr")
    public suspend fun licenseType(`value`: Either<String, ArcSqlManagedInstanceLicenseType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.licenseType = mapped
    }

    /**
     * @param value The license type to apply for this managed instance.
     */
    @JvmName("lmshujcxudrdfvyw")
    public fun licenseType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ArcSqlManagedInstanceLicenseType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.licenseType = mapped
    }

    /**
     * @param value The license type to apply for this managed instance.
     */
    @JvmName("gxjfeefllkjwlfvu")
    public fun licenseType(`value`: ArcSqlManagedInstanceLicenseType) {
        val toBeMapped = Either.ofRight<String, ArcSqlManagedInstanceLicenseType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.licenseType = mapped
    }

    /**
     * @param value The instance start time
     */
    @JvmName("pciuknnktkdgcnqe")
    public suspend fun startTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.startTime = mapped
    }

    internal fun build(): SqlManagedInstancePropertiesArgs = SqlManagedInstancePropertiesArgs(
        activeDirectoryInformation = activeDirectoryInformation,
        admin = admin,
        basicLoginInformation = basicLoginInformation,
        clusterId = clusterId,
        dataControllerId = dataControllerId,
        endTime = endTime,
        extensionId = extensionId,
        k8sRaw = k8sRaw,
        lastUploadedDate = lastUploadedDate,
        licenseType = licenseType,
        startTime = startTime,
    )
}
